@@ -34,8 +34,8 @@
 # Version
 # =======
 import sys, time
-__version__= "2020.08.24"
-__moniker__ = "Spruce tip mead"
+__version__= "2020.12.16"
+__moniker__ = "Beskar"
 #datetime.datetime.utcnow().strftime("%Y.%m")
 __author__ = "Josh L. Espinoza"
 __email__ = "jespinoz@jcvi.org, jol.espinoz@gmail.com"
@@ -78,7 +78,7 @@ from .transmute import transmute
 # Tree
 from .tree import tree
 # Utilities
-from .utils import utils, Chromatic, pv
+from .utils import utils, Chromatic, pv, Suppress
 # Visualizations
 from .visuals import visuals
 
